pub struct CredentialEvent {
pub new_expiry: SystemTime,
}Expand description
Credential lifecycle event.
Fired on initial registration and any subsequent renewal (via
Workload::on_credential_renewed), and also used to warn when an
active credential is approaching its expiry (via
Workload::on_credential_expiring).
Fields
new_expiry: SystemTimeAbsolute expiry time of the credential that triggered the event.